#!/bin/bash

check_env() {
    [ -z "$1" ] && echo "$2 is not set" && exit 1
}

check_sanity() {
    [ ! -d "$1/$2" ] && echo "$1 isn't a valid path" && exit 1
}

override_dll() {
    wine reg add "HKEY_CURRENT_USER\Software\Wine\DllOverrides" /v $1 /d native /f
}

check_env "$WINEPREFIX" WINEPREFIX
check_sanity "$WINEPREFIX" drive_c

# User instructions:
# Set PROTON to a Proton folder just like WINEPREFIX, pass -proton to script
if [ "$1" = "-proton" ]; then

    check_env "$PROTON" PROTON
    check_sanity "$PROTON" dist/bin

    export PATH="$PROTON/dist/bin:$PATH"
    export WINESERVER="$PROTON/dist/bin/wineserver"
    export WINELOADER="$PROTON/dist/bin/wine"
    export WINEDLLPATH="$PROTON/dist/lib/wine:$PROTON/dist/lib64/wine"

fi

set -e
export WINEDEBUG="-all"

scriptdir="$(dirname "$(realpath "$0")")"
cd "$scriptdir"

cp -vf syswow64/{libssp-0,FAudio,x3daudio1_*,xactengine3_*,xapofx1_*,xaudio2_*,SDL2,libwinpthread-1,libjpegxr,libjxrglue}.dll "$WINEPREFIX/drive_c/windows/syswow64"

#for file in libffi-7.dll libgcc_s_seh-1.dll libglib-2.0-0.dll libgmodule-2.0-0.dll \
#	 libgobject-2.0-0.dll libgstapp-1.0-0.dll libgstaudio-1.0-0.dll libgstbase-1.0-0.dll libgstreamer-1.0-0.dll libgsttag-1.0-0.dll libintl.dll liborc-0.4-0.dll libgstaudio-1.0-0.dll libgsttag-1.0-0.dll libz.dll

# Copying files for gstreamer
for file in libgcc_s_seh-1.dll libavcodec-58.dll libavdevice-58.dll libavfilter-7.dll libavformat-58.dll libavresample-4.dll libavutil-56.dll libffi-7.dll libges-1.0-0.dll libgio-2.0-0.dll libglib-2.0-0.dll libgmodule-2.0-0.dll libgobject-2.0-0.dll libgraphene-1.0-0.dll libgstadaptivedemux-1.0-0.dll libgstallocators-1.0-0.dll libgstapp-1.0-0.dll libgstaudio-1.0-0.dll libgstbadaudio-1.0-0.dll libgstbase-1.0-0.dll libgstbasecamerabinsrc-1.0-0.dll libgstcheck-1.0-0.dll libgstcodecparsers-1.0-0.dll libgstcodecs-1.0-0.dll libgstcontroller-1.0-0.dll libgstfft-1.0-0.dll libgstgl-1.0-0.dll libgstinsertbin-1.0-0.dll libgstisoff-1.0-0.dll libgstmpegts-1.0-0.dll libgstnet-1.0-0.dll libgstpbutils-1.0-0.dll libgstphotography-1.0-0.dll libgstplayer-1.0-0.dll libgstreamer-1.0-0.dll libgstriff-1.0-0.dll libgstrtp-1.0-0.dll libgstrtsp-1.0-0.dll libgstrtspserver-1.0-0.dll libgstsctp-1.0-0.dll libgstsdp-1.0-0.dll libgsttag-1.0-0.dll libgsttranscoder-1.0-0.dll libgsturidownloader-1.0-0.dll libgstvalidate-1.0-0.dll libgstvalidate-default-overrides-1.0-0.dll libgstvideo-1.0-0.dll libgstwebrtc-1.0-0.dll libgthread-2.0-0.dll libintl.dll libjson-glib-1.0-0.dll libmicrodns.dll libopenh264-6.dll liborc-0.4-0.dll liborc-test-0.4-0.dll libpostproc-55.dll libpsl-5.dll libsoup-2.4-1.dll libsoup-gnome-2.4-1.dll libsqlite.dll libswresample-3.dll libswscale-5.dll libxml2.dll libz.dll
do 
	cp -vf system32/${file} "$WINEPREFIX/drive_c/windows/system32"
	#override_dll "${file}"
done

cp -v system32/{libssp-0,FAudio,x3daudio1_*,xactengine3_*,xapofx1_*,xaudio2_*,SDL2,libwinpthread-1,libjpegxr,libjxrglue}.dll "$WINEPREFIX/drive_c/windows/system32"

override_dll "libssp-0"
override_dll "FAudio"
override_dll "libwinpthread-1"
override_dll "SDL2"
override_dll "x3daudio1_3"
override_dll "x3daudio1_4"
override_dll "x3daudio1_5"
override_dll "x3daudio1_6"
override_dll "x3daudio1_7"
override_dll "xactengine3_0"
override_dll "xactengine3_1"
override_dll "xactengine3_2"
override_dll "xactengine3_3"
override_dll "xactengine3_4"
override_dll "xactengine3_5"
override_dll "xactengine3_6"
override_dll "xactengine3_7"
override_dll "xapofx1_1"
override_dll "xapofx1_2"
override_dll "xapofx1_3"
override_dll "xapofx1_4"
override_dll "xapofx1_5"
override_dll "xaudio2_0"
override_dll "xaudio2_1"
override_dll "xaudio2_2"
override_dll "xaudio2_3"
override_dll "xaudio2_4"
override_dll "xaudio2_5"
override_dll "xaudio2_6"
override_dll "xaudio2_7"
override_dll "xaudio2_8"
override_dll "xaudio2_9"
override_dll "libjpegxr"
override_dll "libjxrglue"
